Internal function. This function identifies the extent of any NA in a ChemoSpec2D::Spectra2D() object.
This information can be used for summaries and plots.
.findNA(spectra, retFreq = FALSE)A list with two elements giving the indices of NAs for rows and columns,
unless retFreq = TRUE, in which case the frequencies are returned.
An object of S3 class ChemoSpec2D::Spectra2D().
Logical. Should the frequencies be returned?
Bryan A. Hanson (DePauw University).