Internal function. This function plots the results of an HCA analysis.
.plotHCA(spectra, hclst, sub.title, use.sym, leg.loc, ...)An object of class dendrogram. Side effect is a plot.
An object of S3 class ChemoSpec::Spectra() or ChemoSpec2D::Spectra2D().
A hclust object.
A character string for the subtitle.
Logical; if true, the color scheme will be black and
lower-case letters will be used to indicate group membership.
Applies to Spectra objects only.
Character; if "none" no legend will be drawn.
Otherwise, any string acceptable to legend.
Parameters to be passed to the plotting routines. Applies to base graphics only.
Bryan A. Hanson (DePauw University).