Internal function.
.remGrpSam(spectra, kill, group = TRUE)An object of S3 class ChemoSpec::Spectra() or ChemoSpec2D::Spectra2D().
An object of S3 class ChemoSpec::Spectra() or ChemoSpec2D::Spectra2D().
A vector of character strings giving a regex pattern to be applied to the sample
or group names. If group = FALSE can also be an integer vector giving the samples
to be removed.
Logical. TRUE means we are removing groups. FALSE means we are removing samples.
Bryan A. Hanson (DePauw University).